# Auto-generated full reflection for com.android.billingclient.api.ProductDetails$RecurrenceMode
# Source: javap -s output
__all__ = ("RecurrenceMode",)

from jnius import JavaClass, MetaJavaClass, JavaStaticField


class RecurrenceMode(JavaClass, metaclass=MetaJavaClass):
    __javaclass__ = "com/android/billingclient/api/ProductDetails$RecurrenceMode"

    # static fields
    FINITE_RECURRING = JavaStaticField("I")
    INFINITE_RECURRING = JavaStaticField("I")
    NON_RECURRING = JavaStaticField("I")
